@@ -14,24 +14,11 @@ fn scan(build: &mut Build, path: &str, suffix: &str) {
     }
 }
 
-#[cfg(feature = "static")]
-fn builder() -> Build {
-    return cc::Build::new();
-}
-
-#[cfg(not(feature = "static"))]
-fn builder() -> Build {
-    let mut build = cc::Build::new();
-    build.static_flag(false);
-
-    return build;
-}
-
 fn main() {
     println!("cargo:rerun-if-changed=src/shim/wrapper.h");
     println!("cargo:rerun-if-changed=src/shim/wrapper.c");
 
-    let mut c = builder();
+    let mut c = cc::Build::new();
     c.warnings(false);
 
     scan(&mut c, "./src/shim/", ".c");
